#
# spec file for package indi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} < 1590
%global force_gcc_version 12
%endif

%define so_ver 2
Name:           indi
Version:        2.1.2.1
Release:        2.1
Summary:        Instrument Neutral Distributed Interface
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND GPL-3.0-or-later
Group:          Productivity/Scientific/Astronomy
URL:            https://www.indilib.org/
Source0:        https://github.com/indilib/indi/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        indi-rpmlintrc
BuildRequires:  cmake
BuildRequires:  gcc%{?force_gcc_version}-c++ >= 12
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%if 0%{?sle_version} > 150500 || 0%{?suse_version} >= 1600
BuildRequires:  cfitsio-devel
%else
BuildRequires:  libcfitsio-devel
%endif
BuildRequires:  libXISF-devel
BuildRequires:  libev-devel >= 4.33
BuildRequires:  liblz4-devel
BuildRequires:  libnova-devel
BuildRequires:  pkgconfig
BuildRequires:  pugixml-devel
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(zlib)
Requires:       indi-plugins = %{version}
Provides:       libindi = %{version}-%{release}
Obsoletes:      libindi < %{version}-%{release}

%description
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package devel
Summary:        Development files for libindi
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libindiAlignmentDriver%{so_ver} = %{version}
Requires:       libindiclient%{so_ver} = %{version}
Requires:       libindiclientqt%{so_ver} = %{version}
Requires:       libindidriver%{so_ver} = %{version}
Requires:       libindilx200-%{so_ver} = %{version}
Provides:       libindi-devel = %{version}-%{release}
Obsoletes:      libindi-devel < %{version}-%{release}

%description devel
This package contains development files for libindi.

%package plugins
Summary:        Plugins for libindi
Group:          Productivity/Scientific/Astronomy
Provides:       libindi-plugins = %{version}-%{release}
Obsoletes:      libindi-plugins < %{version}-%{release}

%description plugins
This package contains plugins for libindi.

%package -n libindiAlignmentDriver%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindiAlignmentDriver%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package -n libindidriver%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindidriver%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package -n libindilx200-%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindilx200-%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package -n libindiclient%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindiclient%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package -n libindiclientqt%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindiclientqt%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%prep
%autosetup -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
export CFLAGS="%(echo %{optflags}) -Wno-stringop-truncation"
export CXXFLAGS="$CFLAGS"

%cmake \
    -DINDI_BUILD_STATIC=OFF \
    -DUDEVRULES_INSTALL_DIR=%{_udevrulesdir} \
    -DINDI_BUILD_QT5_CLIENT=ON \
    -DINDI_BUILD_WEBSOCKET=OFF \
    -DINDI_BUILD_XISF=ON \
%if 0%{?force_gcc_version}
    -DCMAKE_CXX_COMPILER=%{_bindir}/g++-%{?force_gcc_version} \
%endif
    -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now"
%cmake_build

%install
%cmake_install

# delete static libs
find %{buildroot}%{_libdir} -iname "*.a" -delete

%ldconfig_scriptlets -n libindiAlignmentDriver%{so_ver}
%ldconfig_scriptlets -n libindidriver%{so_ver}
%ldconfig_scriptlets -n libindilx200-%{so_ver}
%ldconfig_scriptlets -n libindiclient%{so_ver}
%ldconfig_scriptlets -n libindiclientqt%{so_ver}

%files
%license COPYING.* COPYRIGHT LICENSE
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/indi*
%{_bindir}/shelyak_usis
%{_datadir}/indi/
%{_udevrulesdir}/*.rules

%files devel
%license COPYING.* LICENSE
%{_includedir}/libindi/
%{_libdir}/pkgconfig/libindi.pc
%{_libdir}/libindi*.so

%files plugins
%license COPYING.* LICENSE
%{_libdir}/indi/

%files -n libindiclient%{so_ver}
%{_libdir}/libindiclient.so.%{so_ver}
%{_libdir}/libindiclient.so.%{so_ver}.*

%files -n libindiclientqt%{so_ver}
%{_libdir}/libindiclientqt.so.%{so_ver}
%{_libdir}/libindiclientqt.so.%{so_ver}.*

%files -n libindiAlignmentDriver%{so_ver}
%{_libdir}/libindiAlignmentDriver.so.%{so_ver}*

%files -n libindidriver%{so_ver}
%{_libdir}/libindidriver.so.%{so_ver}*

%files -n libindilx200-%{so_ver}
%{_libdir}/libindilx200.so.%{so_ver}*

%changelog
* Tue Mar 11 2025 Paolo Stivanin <info@paolostivanin.com>
- Disable websocketpp: with next release websocketpp will be completely
  dropped by INDI because the project is no longer maintained.
  https://github.com/indilib/indi/commit/4ebb20caa3618efcdb014405e396dd52065073af
* Thu Feb 20 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.1.2.1:
  * Add buffer check
* Sat Feb  1 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.1.2:
  * Fix DustCover open/close by @peter-englmaier in #2152
  * Draft: Reuse calibration after rotation by @escribana in #2153
  * Use C99 integer types by @brad0 in #2160
  * Feature for ZWO AM5 - Heavy Duty Mode and Fix slew rate by @pawel-soja in #2161
  * Add includes to fix build with GCC15-C++23 by @mattiaverga in #2165
  * Update wanderer rotator lite v1 to latest firmware version and correct a bug when homing with rotator mini and lite v2 by @grm in #2166
* Mon Dec  9 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.1.1:
  * Fixed missing apply() on TrackStateSP property by @atoy40 in #2130
  * Update SnapCap driver to use common abort capability from DustCapInterface instead of doing it manually. by @jpaana in #2136
  * Miscellaneous ScopeDome driver updates. by @jpaana in #2137
  * FP2 motor status by @DeepSkyDad in #2139
  * Migrate INDI Astrolink4 by @naheedsa in #2133
  * Migrate Astromech focuser by @naheedsa in #2134
  * Update ieaffocus.cpp by @joe13905179063 in #2141
  * Fixed crash due not checking boundary values of the axis in telescope_simulator by @artyom-beilis in #2144
  * Upgrade CheapoDC driver for new device firmware features by @hcomet in #2142
  * Sim crash fix - looks like found root cause by @artyom-beilis in #2147
* Tue Oct  1 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.1.0:
  * Initial work for guider and focuser interface refactor
  * Fixed myFocuserPro2 Autofocus Issues in Ekos
  * Update Tracking code
  * Add workaround for OnStepX failing connection
  * Migrate telescope properties
  * Migrate Temperature Property
  * Update light box and dust cap interfaces to new style
  * drivers/dome: rigel_dome shutter parking
  * Joining FP1 and FP2 into single FP driver
  * lx200zeq driver had incorrect pulse commands
  * Fix Motion Control Mode
  * use MOTION_CONTROL_MODE _FOO enums
  * enable more Meade commands
* Fri Aug 30 2024 Max Lin <mlin@suse.com>
- To use cfitsio-devel on 16.0 as well not just greater than 16.0
* Fri Aug  2 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.9:
  * Minor buffer boundary fixes
  * Weather watcher dynamic labels
  * PegasusAstro FalconV2 Driver
  * Add Terrans PowerBoxPro V2 Driver
  * Waveshare Modbus Relay Drive
  * Universal Roll off roof driver
  * ZWO AM5 Save home position in the mount
* Mon Jun 10 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.8:
  * Avoid using .getName() for new INDI properties
  * Migrate drivers to new properties
  * Various fixes
* Wed May 29 2024 Paolo Stivanin <info@paolostivanin.com>
- Use ldconfig_scriptlets macro
* Tue Apr  2 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.7:
  * Update Pegasus Focuscube
  * New driver for DIY dew controllaer cheapodc
  * Weather interface refactor
  * Driver for Wnaderer Box and Cover products
  * Initial release of Alluno TCS2 driver
* Thu Feb  1 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.6:
  * Link against httplib if using system libraries
  * fix(actions): upgrade actions versions
  * Fix various typos throughout the codebase
  * Remove obsolete Avalon Legacy driver
  * TeenAstro pulse behaviour #1977
  * iOptron iEAF indi driver
  * Allow using system provided json library
  * Flip-flat: Allow handshake without ioctl on virtual serial connection
  * Fix version reporting on older Celestron NexStar mounts
  * PegasusAstro SaddlePowerBox
* Tue Dec  5 2023 Paolo Stivanin <info@paolostivanin.com>
- Rename libindi to indi.
* Mon Dec  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.5:
  * Fix issue 1938
  * Add one more check to ensure minimum count is met
  * Update ioptronv3driver.cpp
  * Handling tracking mode in the pegasus driver, and enable King mode
  * Fixed 9 Stars Align
  * On step work
  * Added several missing commands
  * Snapcap driver with network connections
* Wed Oct  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.4:
  * Fix bug in relative positioning of Lacerta MFOC
  * Fix setFormat typos, add isEmpty method
  * Use ZSTD compression for XISF images when available
  * Preliminary support for Planewave
  * Bug fix making both focusers visible
  * focuser crash fixed+some properties added
  * OnStep work
  * Openastrotech work
* Fri Sep 29 2023 Paolo Stivanin <info@paolostivanin.com>
- Force usage of GCC>=12 on Leap.
* Tue Aug  1 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.3:
  * Simplify RTL-SDR driver for bug #558
  * Update ioptronv3.cpp
  * Fix leaks last blob on driver restart
* Fri Jun  2 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.2:
  * Minor Fixes discrepancies Indi / SmartwebServer
  * Add Flip functionality
  * Pegasus NYX-101
  * Bugfix/mfoc rel movement error
  * Fix AutoPA lx200 OpenAstroTech
  * Esatto: Port state tracking from EsattoArco
  * PLL: Treat ERR messages as out-of-bound warnings
* Tue Apr  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.1:
  * Resolve timestamp name conflict.
  * Fix PMC8 tracking rate.
  * Support for XISF files.
  * Update DDW dome driver for new property functions.
  * Added Safety and Goto Limits.
  * Feature/qhy gps timestamp.
  * Addition of myDewControllerPro driver.
  * Southern Hemisphere Support for PMC8.
  * Fixed regression with Servo Precision logic setting.
  * [WandererCover] Adding support for newer firmware (20221008).
  * Add driver for myDCP4ESP32 Dew Contoller.
  * Focuser Temperature Compensation minor fixes.
  * Fixing Openastrotech AutoPA.
  * Fixed SestoSenso2 calibration.
  * Force enable tracking after slew and unpark.
- Remove fix-operator.patch
- Remove fix-timestamp.patch
* Thu Mar 23 2023 Martin Liška <mliska@suse.cz>
- Enable LTO as it builds fine.
* Fri Mar 10 2023 Paolo Stivanin <info@paolostivanin.com>
- Revert hwcaps.
* Wed Mar  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Build AVX2 enabled hwcaps library for x86_64-v3
* Wed Feb  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Add fix-operator.patch (#1843)
- Add fix-timestamp.patch (#1837)
* Tue Jan 31 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.0:
  * Esatto & SestoSenso2 update
  * Fix for issue1582 park status notifications and extra debugging for command errors
  * Add delay possibility for lx200 driver pulse command
  * Refactor - use PropertyView/WidgetView
  * Fix BaseClient::serverDisconnected behavior
  * Deprecated use of Property/BaseDevice as pointer
  * Don't modify usbfs_memory_mb if already set to unlimited
  * Switch Flip Points to use sexagesimal numbers
  * Refactor INDI::GPS to be inline with INDI 2.0.0
  * General cleanup
  * Don't call serverDisconnected if the client is not connected
  * Add refraction, and turn off J2000 for Gemini
  * Feature/new firmware fmc mfoc (Lacerta)
  * Downgrade to base64 for snooped blobs
* Sun Dec 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Fix cfitsio dep on TW
* Wed Nov 30 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.9:
  * Driver for OpenAstroTech mounts
  * DRIVER_INFO also present for F2 focuser so that the device is detected
  * DeepSkyDad AF3: Mark as OK after backlash compensation
  * Add Excalibur Driver
  * Improved star brightness handling for higher gain
  * Add Gemini L6 Flip Point
  * lx200_OnStep minor fix
  * Add missing rule for switch
  * Fix client disconnect event
  * Update weather interface to define update period, refresh and override
* Thu Sep 29 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.8:
  * Remove some debug message from indiserver.
  * Don't tell cfitsio about preallocated buffers.
  * Corrections for Pegasus Falcon Rotator.
  * Fix blob id conflit.
  * Adding wanderer cover v3.
  * Fix memory leaks in indiserver.
- Drop add-hem27.patch
- Drop fix-cfitsio.patch
- Drop fix-ioptron-meridian.patch
- Drop fix-ioptron-timeout.patch
- Drop fix-pegasus.patch
* Wed Aug 17 2022 Paolo Stivanin <info@paolostivanin.com>
- Add fix-cfitsio.patch: FITS files produced by INDI are invalid because there is extra data at the end of the file.
  Many software only read the first HDU are not affected, but other reject the file.
- Add fix-pegasus.patch: Corrections for Pegasus Falcon Rotator.
* Sun Aug 14 2022 Paolo Stivanin <info@paolostivanin.com>
- Add add-hem27.patch: add support for iOptron HEM27 mount.
* Thu Aug  4 2022 Paolo Stivanin <info@paolostivanin.com>
- Add fix-ioptron-meridian.patch: add again in case a timeout is issued
  and iOptron returns it despite the flush. This is an attempt to read this buffer again.
- Add fix-ioptron-timeout.patch: save meridian flip settings by default on change.
* Fri Jul 29 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.7:
  * INDI Receiver and rtl-sdr.
  * Ensure defensive check of UBP previous data to fix crash.
  * Fast blob transfer.
  * More AP changes: UDP, Home, Encoder Status, version major/minor.
  * Fix memory leak when converting blob to base64.
  * Use 8bits samples in the lookup table.
  * Adding some basic PEC status and control to lx200gemini.
  * Add Servo Precision control.
  * Added RA/DEC guide speed.
  * Fixed a bug where PEC was always enabled on startup.
  * Various other fixes.
* Sat May 21 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.6:
  * add lastparked logic
  * Fixing UTC Offset format allowing :SGHH:MM# where MM can be 00, 30 and 45
  * Terminate commands missing #, introduce PEC recording and status
  * fix issue reading worm position
  * UTC uninitialized structure fix
  * Add mount status. Start CP5
  * Remove user choice for CM/CMR
  * Allow any guide rate between 0.1x and 1x
  * Driver for WandererRotatorLite
* Thu Mar 10 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.5:
  * Fixed updating of slew rate
  * Add missing find_package for Qt5Core
  * Fix setObjectRA and setObjectDEC for short and long format
  * Allow Minutes Past Meridia +/- 180 degrees
  * Adding new NexDome Beaver INDI driver
  * Add and apply Meade Protocol spec definitions
  * Add Pier Side Status for lx200zeq25
  * Updated version of the AstroPhysics driver
  * Fix Celestron focuser crash after calibration
  * Fix but setting AP UTC
  * Fix similar negative sign bug in AP driver
  * Initial implementation for capture format and encode format
  * Update driver interface when the LX200 support a focuser
  * Add CEM70(G)-EC identifier and a deprecation note
  * Add Driver for Esatto with Arco (goto, abort, sync, cal)
- Remove 0001-Fix-warnings.patch
* Tue Jan 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.4:
  * OnStep: Don't show focuser tab unless found.
  * More Lynx fixes - Step Size and Devices Types.
  * OnStep: Remove Focuser on disconnect.
  * Save Alignment Data to mount before sync.
  * CCD drivers: snooping for standard epoch positions and issues
    with fast exposure mode fixed.
  * SkyWatcher Alt-Az iterative GOTO.
  * Add Bayer frames software binning
  * Add driver for Rigelsys/Astrogene1000 nFrame rotator.
  * Send command at start to flush serial line for Pulsar/Rigel dome.
- Remove ioptron_fixes.patch
* Fri Dec 10 2021 Paolo Stivanin <info@paolostivanin.com>
- Add ioptron_fixes.patch (bsc#1193622):
  * Fix PEC being on by default, it should be OFF by default.
  * Fix iOptronV3 parking bug by using a workaround, because the
    firmware must be fixed by iOptron.
  * Add meridian behavior action and limit.
* Fri Nov 19 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.3:
  * Fast Exposure support. Capture next frame in camera immediately
    to avoid any delays.
  * Support for DC focusers in Pegasus DMFC driver.
  * Updates and cleanup for the OpenWeatherMap driver
  * V42L driver supports detecting camera and renaming the driver
  * LX200 SiteName Fix V2
  * Improve lynx sync and homing behavior
  * Fix FocusLynx GetConfig for focusers without HomeOnStart
  * Force using hour angle when mount is slewing
  * Correction the amplification values to spec.
  * Fixes to PlaneWave EFA driver
  * Add setting of home position for Rigel/Pulsar dome
* Wed Sep 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.2:
  * Stable Astrotrac Mount driver.
  * ESATTO Backlash measure and correction
  * Correct color space when stacking on indi_v4l2_ccd driver with
    a web cam that doesn't have color space info.
  * The driver for the Planewave Delta-T was not working
  * Improved handling of myFP2ESP controllers
  * Pegasus UCH
  * TheSkyX/Paramount Pier-side + guide async cmd fixes
  * Update lx200_OnStep.cpp
- Drop fix_include_path.patch
* Mon Jun 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.1:
  * New AstroTrac 360 driver (Experimental).
  * New Pegasus FlatMaster and UHC drivers
  * New Deep Sky Dad Field Rotator
  * Core INDI Library improvements to base device and client classes
  * Paramount TCP improvements
  * Spectrograph and Receiver classes
  * OnStep improvements
  * RST-135 location and time fix
  * Dome OTA fixes
  * Object Azimuth and Altitude added to FITS header
  * Rainbow Focuser fixes
  * Support for CGX-L
  * Fix crash in SkyWatcher API mount driver
  * Fix iOptron DST bug
  * Fix lunar and solar order
  * PMC8 Driver v0.4 (Improved manual slewing, guiding, and other features)
  * Try to send the guide pulses asynchronously to TheSkyX
  * Use encoders for parking
  * Lots of other smmall fixes, for the full changelog please check
    https://github.com/indilib/indi/blob/master/ChangeLog
- Drop ioptron_dst_fix.patch (change has been upstreamed)
- Add fix_include_path.patch
* Tue Jun  8 2021 Paolo Stivanin <info@paolostivanin.com>
- Add ioptron_dst_fix.patch (fix boo#1187058)
  When using iOptron mounts and KStars is set to get time and location
  from the mount itself, if DST is enabled then KStars is off by 1 hour.
  This patch fixes this issue.
* Sat Apr 24 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.0:
  * Major INDI Library release v1.9.0 bring significant internal changes
    championed by @pawel-soja to modernize core INDI Library drivers and clients.
  * New drivers for DeepSkyDad Flat Panel & Pegasus devices plus
    further improvements to PCM8 drivers.
* Mon Mar  1 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.9:
  + Fix paramount home and sidereal rate
  + Added labels for USB and Dew
  + Add entry for star adventurer
  + Add motor rate and current to the config save
  + Add CEM26 and GEM28. Migrate CEM40 and GEM45 drivers to
    iOptronv3 commands and remove parking restrictions
  + Add preliminary support to inquire pier side for Paramount
  + Add support to Pegasus Micro
  + Updates to DDW driver
  + Increment version for SkyWAtcher Alt-Az
  + Add support for AZEQ6
  + Fix celestrongps guide rate scaling
  + Various small fixes
* Mon Jan 11 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.8:
  + New HOBYM Crux telescope driver
  + New Rainbow focuser driver
  + New ActiveFocuser driver release
  + 10Micron: UnattendedFlip handling
  + Bugfix/sat track lx200 julian day
  + Improved serial port auto-search.
  + Refactor/satellite tracking properties
  + SkyWatcher Alt-Az driver improvements.
  + Indibase/refactoring - update INDI::Property
  + Update of SmartFocus driver
  + Add new helper methods to the AlignmentSubsystemForDrivers (Alt/Az)
  + Streammanager/chrono - Fix the 24h time limit
  + Fix remote driver not sending properties to upstream server
  + Delay calculation in indicommon and indicorrelator (#1277)
  + Indidriver/refactoring - fix memory leak, increase performance
  + Streammanager/refactoring
  + Move absolute position bugfix
  + Use of the common mkpath function
  + Sesto Senso 2: Support for displaying 12V input voltage
  + Add Microsoft LifeCam Cinema to pixelSizeInfo
  + Sesto Senso 2: Log & display firmware version
  + fix: inline methods that use unlinked functions
* Wed Nov 25 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.7:
  + New Esatto focuser support.
  + New Pegasus Falcon Rotator.
  + Fix QHYCFW3 driver handshake
  + Support for AZ-GTi in Alt-Az mode.
  + Improve on deadlocks and integrity
  + Rework/streammanager - fix recording subframe issue, add
    processing qeue, configurable limits memory/fps
  + Baader SteelDrive II - feature, Adjustable holding and move
    current for stepper drive
  + Do not block the stream thread when sending FPS status,
    fix frames discarding.
  + Many bug fixes and additions supporting advanced
    Pulsar2 features
  + Add support to connecting to all remote drivers without
    specifying an explicit driver.
  + Added Humidity, Pressure and Clouds to the
    WeatherWatcher driver
  + Fixed Losmandy Gemini failed to complete park issue
  + Set Eq Coords property state to OK & IDLE as needed
  + 1st fix for CEM25p Slewing to home position while parked
  + DSP Improvements
  + Compatibility fixed for SteelDriver II.
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.8.6:
  * New Pegasus PPBA driver.
  * New DomePro2 driver.
  * Add PierSide to indi_ioptron_telescope
  * Fix Pier Side problem on Gemini mounts
  * Goto mode selectable for Alt/Az mounts via an UI Switch.
  * OnStep: Weather sensor (READ) support
  * OnStep: Support for setting temperatures for dew heaters/focusers
  * Fix skywatcher altaz crash
  * Add the focus temperature property to the focus simulator
  * Logitech HD C270 webcam data added to v4l2_ccd driver
  * Astrophysics park3 support
  * Implement Parking for LX200 classic
  * UDP support for skywatcherAPI
  * LX200 FS-2 Park
  * Telescope Simulator Parking to HA/Dec frame
  * Update Pointing State determination.
  * Feature Satellite tracking with TLE for 10Micron mounts
  * Add focuser temperature to FITS header
  * myFocuserPro2 Fix coil power command
  * Updated TeenAstro INDI driver for firmware 1.2.0
- Use %%cmake_build instead of %%make_jobs
* Mon Apr 27 2020 wbauer@tmo.at
- Update to version 1.8.5:
  * New PlaneWave EFA driver.
  * New PlaneWave Delta-T driver.
  * New SestoSenso2 driver.
  * New Lunatico DragonFly Rolloff driver.
  * New Lunatico Seletek Rotator driver.
  * New Radio Astronomy Interferometer Driver.
  * Fixed parking in Temma driver.
  * Improved Slew accuray for Celestron mounts.
  * Improved TeenAstro Mount driver.
  * Fixed declination issue in Rainbow driver.
  * Fixed Guide problem with StarSense.
  * Fixed AAG driver and Weather Parameters state.
  * Fixed OnStep Speed change
  * Added Park3 to AP mount driver.
  * Improved XAGYL driver.
  * Added hour axis offset to CCD Simulator.
  * Added FOCUSPOS to the FITS header.
  * Updated Telescope Simulator Driver.
- Drop remove-unused-websocket-block.patch, merged upstream
* Mon Feb 24 2020 wbauer@tmo.at
- Update to version 1.8.4:
  * New TeenAstro Mount driver.
  * New DSP plugin for Signal Processing.
  * New INDI interface for correlators.
  * Draft for Pulse Detectors (revealers, dosimeters, cosmic ray).
  * Created SensorInterface and Spectrograph, Detector subclasses.
  * Celestron PEC control is added that provides seek index, stop,
    playback and record commands.
  * Celestron negative UTC fix.
  * Fixed iOptron mount firmware parsing.
  * Fixed version read in MoonLite focuser.
  * DeepSkyDad3 backlash compensation.
  * CCD Simulator bayer support.
  * FCUSB2 support.
  * Fixed complation on FreeBSD.
- Add remove-unused-websocket-block.patch to fix build with
  websocketpp
- Remove conditionals for outdated distribution versions
* Tue Jan 14 2020 wbauer@tmo.at
- Update to version 1.8.3:
  * New RainbowAstro Mount driver.
  * New Simulated Pier Side option for all mounts.
  * Added iOptron GEM45 support. (#1041)
  * Added *preliminary* support for iOptron iPolar. (#1043)
  * Update Celestron GPS Guide (#1048)
  * Bug fix: meridian flip working for longer polling intervals
    (#1042)
  * Update Celestron GPS Guide (#1048)
  * Added recording the absolute position of the focuser to the
    FITS header (#1052)
  * Fix enabling/disabling DMFC properties and remove dead code
    (#1050)
  * Enable saving/loading backlash steps and fix motor type select
    (#1055)
* Sat Nov  9 2019 wbauer@tmo.at
- Update to version 1.8.2:
  * First release of INDI separate from INDI 3rd party repository.
  * New Pular Domes driver.
  * New MyFocuserPro2 driver.
  * New SteelDriverII focuser driver.
  * New Deep Sky Dad AF3 driver.
  * Fixed INDI Client build on Windows.
  * Fixed weather override functionality in INDI::Weather.
  * Fixed INDI Dome tracking.
  * Updated PCM8 driver to automatically detect mount types.
  * Serial communication polling period is configurable 1-30 secs.
  * Added ISGetConfigSwitch to read switch information directly
    from config.
  From version 1.8.1:
  * Unified Toupbase driver for Touptek-based cameras.
  * Support for native backlash handling in INDI::FocuserInterface
  * Apogee fan control support.
  * Fixed Bluetooth serial port connectivity.
  * Updated version of OnStep driver (v1.8), fixes for Fork Mounts.
  * Pegasus Ultimate Power Box v2 support.
  * Fixed Celestron GPS focuser position.
  * Fixed parking mode initialization for roll-off roofs.
  * Fixed various FocusLynx issues and added Optec Sagitta focuser.
  * LX200 Based mount migrated to INDI::FocuserInterface
  * QHY SDK updated to 6.0.1.
  From version 1.8.0:
  * iOptron CEM40 driver.
  * QHYCCD CFW1 driver.
  * Decode ATIK firmware version correctly.
  * Apply gamma when downscaling 16bit to 8bit stream.
  * Improve reliability of sendBlob.
  * GPSD driver should use raw GPS time by default.
  * add watchProperty to make client only request and only process
    properties of interest.
  * Prevents indi_fli_wheel crash for FLI-CFW-1-8 model.
  * Fix communication issues in Vixen Starbook driver.
  * Fix Dew control and Current sensing on PPB.
  * Fix out-of-bounds access in 420p conversion in V4L2 driver.
  * Fix Atik guide ST4 pulses.
  * ASI Camera SDK 1.14.0715 update.
  * QHY SDK updated to 5.1.0.
- Refresh 0001-Fix-warnings.patch
* Tue Jul  9 2019 wbauer@tmo.at
- Update to version 1.7.9:
  * New Astromechanic Light Pollution Meter driver.
  * New FCUSB driver.
  * SestoSenso driver motion issues resolved.
  * LX200 drivers can operate over TCP.
  * Fix TCFS issue when temperature sensor is not connected.
  * Experimental support for KMTronic USB Relay Serial for Nikon cameras.
  * Fix RA drift with HEQ5 firmware 106.
  * Added dead-zones to joystick driver.
  * Update ASI EAF SDK to version 0.1.0524.
  * QHY SDK updated to 5.0.9.
  From version 1.7.8:
  * New Omegon EQ500X mount driver.
  * New TALON6 dome driver.
  * New Astromechanics focuser driver.
  * New DeepSkyDad AF2 focuser driver.
  * New Apogee CFW filter wheel driver.
  * Support for Radio Detector Streaming.
  * ScopeDome fixes and improvements.
  * Fixed Vixen Starbook version detection bug.
  * Fixed Avalon Stargo Connect/Disconnect issue.
  * Improved detection of Quantum wheel.
  * Update Celestron SCT focuser to prevent moves when not calibrated.
  * Improve Sync, Park, Focus Max in DreamFocuser driver.
  * Implemented UI for PWM Outputs for OnStep
  * Fixed subframe capture in QHY driver.
  * ASI SDK updated to v1.14.0425.
  * QHY SDK updated to 5.0.5.
- Disable LTO to fix build on Tumbleweed/x86_64
* Sat Apr 27 2019 wbauer@tmo.at
- Update to version 1.7.7:
  * New DreamFocuser driver.
  * New BeeFocus driver.
  * New Weather Safety Proxy driver.
  * Nexdome driver rewritten to INDI standards.
  * DSP & Radio Detector improvements.
  * Vixen Starbook driver received numerous updates and fixes.
  * Celestron driver supports focuser control directly.
  * Celestron driver resumes from last alignment. Fixed
    hibernation.
  * Fixed QHY filter wheel issues & live streaming.
  * Fixed QHY temperature controls in manual and auto modes.
  * ATIK SDK updated & fixed filter wheel issues.
  * Fix bulb exposures initiated with shutter release cable on
    Pentax cameras.
  * QHY and SDR drivers enabled back on MacOS.
  * Weather drivers offer a weather override toggle.
  * All iOptron drivers now park to Alt/Az coordinates.
  * Dome and Telescope scripts use safer methods to create
    temporary files.
  * Enhanced performance and reliability of SestoSenso driver.
  * Enhanced and extended telescope joystick controls.
  * ASI SDK updated to v1.14.0227. Fixed asynchronous image
    loading.
  * QHY SDK updated to 5.0.3.
* Tue Mar 26 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.7.6.
  Changes in 1.7.6:
  * Support for compressed FITS files via fpack lossless compression.
  * Fixed USBFocusV3 connection issues.
  * Improve indiserver message queue memory management.
  * Fix bulb exposures initiated with shutter release cable on Pentax cameras.
  * Fix negative declination issue in synscan.
  * Added fix for QHY5-M- CancelQHYCCDExposing* crash
  * Fixed Temma guiding with PHD2.
  * Fixed TCFS position and temperature.
  * Fixed race condition when using multiple devices that can park.
  * Fixes to INDI::Weather interface.
  * Initialize backlash on eqmod connect.
  * Focuser Interface should now natively support Focus Max Limit, Sync, and Reverse Direction.
  * Preliminary support for Websockets in INDI::CCD. It is off by default.
  Changes in 1.7.5:
  * Add fallback shutters speed for some GPhoto cameras.
  * Add pier side support to Celestron and Synscan drivers.
  * Add focus limits to SestoSenso driver.
  * Major update to USBFocusV3 driver.
  * Added stream struct and some astronomic helpers to libdspau.
  * OnStep fixes and updates.
  * FocusLynx refactor and updates.
  * Geographic location update fixes in mount driver.
  * Parking support in SS2000PC mount.
  * TCFS refactoring and fixes.
  * WeatherWatcher socket bug fixes.
  * Fix Synscan J2000 epoch issue.
  * Add XPIXSX and YPIXSX for logical binned pixel size.
  * Fix problem with handling XML entities between clients, servers, and drivers.
  * Fix feature stacking streamed frames to simulate absolute exposure.
  * Fix iOptron guide rates.
  * Fix iOptron calender setting.
  * Removed Zulu prefix in FITS header timestamp.
  Check https://github.com/indilib/indi/releases for the complete changelog
- Add 0001-Fix-warnings.patch
- Remove binary blobs and unneded folders before building the package
* Thu Oct 25 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.7.4
  * Optec IFW to support TCP/IP.
  * Added color support for OGV recorder.
  * Pulse Command now turned on by default.
  * Add DSLR temperature reporting.
  * Add support for GRBG pixel layout (8-bit) used by things such as NexImage 5.
  * Fixex pier side reporting for 10Micron mounts.
  * Fixed protocol issue with ethernet connection to AP GTOCP4.
  * Fixed Celestron Pulse guiding.
  * Fixed occasional filter loading issues.
  * Add additional FITS Keyword SITELAT and SITELONG.
  * Add custom max filter count to trutech.
  * Add Zulu postfix to UTC time in FITS header.
  * Increase usbfs_memory to 256 for all USB cameras as it helps under ARM architecture.
* Thu Apr 12 2018 wbauer@tmo.at
- Update to version 1.7.1:
  * Hotfix for INDI API version that was not updated properly to
    1.7.0 in the previous release
  * Fixes to Astrophysics driver
  * More code cleanup and refactoring
* Wed Apr 11 2018 wbauer@tmo.at
- Update to version 1.7.0:
  * Updated QHY SDK.
  * FLI drivers are now based on libusb rather than legacy kernel
    driver.
  * New driver for CEM120 mount.
  * New driver for Explore Scientific PMC8.
  * Several memory leaks were fixed.
  * Added support for background flushing for FLI CCDs.
  * Added preliminary support for CCD rapid captures on the
    millisecond range.
  * SX CCD driver updated to support ICX453 & M25C.
  * SX AO driver updated to emply INDI serial connection plugin.
  * Fix timing issue with GPhoto making it stuck in busy state
    after initial capture.
  * ASI driver enhancements. Video format recall fix.
  * MaxDomeII driver refactored and updated.
  * Several fixes for Gemini Integra driver.
  * Polling period for most drivers is now customizable.
  * GPhoto driver supported Abort exposure. Subframing fixes.
  * GPS driver can set system time from GPS source.
  * Astrophyics Experimental Driver with multi-parking support.
  * Numerous OnStep driver fixes and updates.
  * SkySensor2000 Pulse guiding support.
  * Prevent sandbox ACCESS_VIOLATION on Gentoo
  * Celestron driver refactoring and support for high-precision
    formats.
  * Fixed script execution in scripting gateways
  * Fix flags for Cygwin.
  * Fix non-standard POSIX C functions.
  * Replace deprecated usleep with nanosleep.
  * CCD & Telescope simulator updated so that can be used
    effectively in any combination with physical devices.
- Mark license files as %%license instead of %%doc
* Tue Jan  9 2018 wbauer@tmo.at
- Update to version 1.6.2:
  * Another quick release to fix missing cmake_modules directory
    and a joystick driver crash fix.
  From version 1.6.1:
  * This is a bugfix patch release that resolves problems with INDI
    version in INDI API.
  From version 1.6.0:
  * INDI Base Client is now supported on Windows, MacOS, and Linux.
  * Added 10Micron Mount support.
  * Added spectrum support and libDSPAU.
  * Added NexDome support.
  * Added Pyxis Rotator support.
  * Added Pegasus Focuser support.
  * Added MBox Weather box support.
  * Added SnapCap dust cap and flat panel support.
  * Added Sesto-Senso focuser support.
  * Added USB_DewPoint support.
  * Added GPS-NMEA sources support.
  * Added Gemini Telescope Design Integra85 Focusing Rotator WIP
    support.
  * Added Lunatico's Armadillo and Platypus support.
  * Video Streaming support for MacOS.
  * Video Recording with libtheora (Optional).
  * Video Streaming with MJPEG encoder.
  * IOptron fixes and improvements.
  * More NextstarEvo improvements.
  * Dedicated Guider Simulator.
  * QHY & ASI updated to latest SDK.
  * Apogee fixes for MacOS.
  * INova fixes and improvements. Updated SDK.
  * QHY, Apogee, DSI builds for MacOS.
  * EQMod Horizon fixes.
  * Skywatcher Alt-Az Mount & Syncscan fixes and improvements
    including guide support.
  * StarSense support in Celestron Driver.
  * Improvements to mount parking & unparking.
  * New experimental Astrophysics Driver.
  * Support for Losmandy UDP protocol.
  * Fixed Dome slaving slew and tracking.
  * Added Radio Antenna Simulator.
  * New INDI Rotator Interface.
  * UDEV rule to disable automount of DSLR cameras.
  * Sky Quality Meter simulator.
  * Improvements to INDI GPS drivers.
  * TCFS Fixes.
  * SkySensorPC2000 fixes.
  * Fixed WatchDog behavior in case of unavailable dome.
  * Improved Continuous Integration support with Travis & CircleCI
    using Docker.
- Drop cmake_modules.tar.gz, no longer necessary
* Thu Sep 21 2017 wbauer@tmo.at
- Update to version 1.5.0:
  * New Detector Interface for photon and radio detectors.
  * New Software-Defined-Radio driver (RTLSDR).
  * New Connections plugin system to facilitate driver development.
  * New standardized tracking properties system for all mounts.
  * New Digital Settings Circiles (DSC) driver.
  * New Lacerta MGen driver.
  * New NightCrawler Focusing Rotator driver.
  * New Optec Gemini Focusing Rotater driver.
  * New iNovaPLX CCD driver.
  * QHY SDK update to 1.10.0. Support for QHY PoleMaster.
  * QSI SDK update to 7.6.0
  * Support for INDI client under Windows.
  * Support for Pier Side in many mount drivers.
  * Support for SkySafari.
  * Fix FLIUSB for 4.6 and 4.9 kernels.
  * Fixed wrong time format in generated SER files.
  * ZWO ASI drivers for MacOS.
  * Various GPSD fixes.
  * Proper handing of ISO8601 timestamps in the generated
    filenames.
  * Improved Gemini mount driver with more functionality and bug
    fixes.
  * Many V4L2 fixes and improvements. Support for V4L2 integer
    menus.
  * Ability to define multiple primary/guide scope configurations.
  * ZEQ25 Improvements and fixes.
  * NStep driver improvements and fixes.
  * Added Ccache support.
  * Support for Gotonova driver.
  * Added Unity Build support.
  * Improved Astrophysics driver.
  * Added USB connectivity to SQM device driver.
  * More robust handling of reading pier side from mount.
  * Warn client that no devices are detected in case of
    Multiple-Devices-Per-Driver drivers.
  * Added PEC control to INDI::Telescope. Each driver must handle
    the low level protocol to actually enable or disable PEC.
  * Added security (hardening) flags.
  * SoftPEC implementation for Virtuoso mounts in
    skywatcherAPIMount.
  * Added TELESCOP, OBSERVER, and OBJECT keywords to the FITS
    header.
- Add cmake_modules.tar.gz containing cmake modules missing in the
  source tarball to make it build
- Drop bufferoverflow.patch, fixed upstream
* Wed Mar 15 2017 asterios.dramis@gmail.com
- Update to version 1.4.1:
  * Minor bugfix release to fix installation of development headers
    issue in 1.4.0.
  From version 1.4.0:
  * Support for HitecAstro DC Focuser.
  * Support for SQL-LE Sky Quality Meter unit.
  * Support for USB Focus V3.
  * Support for Quantum Filter Wheel.
  * Support for 10micron mounts.
  * ZWO ASI filter wheel support. Driver updated to latest SDK. Fix
    infinite loop exposure.
  * QHY driver updated to latest SDK.
  * Added preliminary support to TCP server connection for all
    mounts.
  * Updated and improved Nexstar Evo driver.
  * Fixed reset of filter wheel names to default values under some
    circumstances.
  * Fixed feedback loop issue in chained INDI server.
  * Handle correctly broken frames in FLI driver; convert time left
    from ms to seconds as it should be.
  * V4L2 CCD driver updated to properly work with DMK cameras.
  * Several bugfixes for Moravian CCD driver.
  * CCD Simulator allows for up to 4096x4096 resolution.
  * Raw color video streaming now uses RGB24 instead of RGBA to
    conserve bandwidth.
  * New Dome and Mount safety interlocks mechanism.
  * Fix the Virtuoso mount detection in SkyWatcherMountAPI driver.
  * Support relative driver paths to INDI server.
  * Fix property cache collision conflict in case of multiple
    devices per driver.
  * Moonlite driver can now sync to any value instead of reset to
    zero.
  * Store OBJECTRA and OBJECTDEC as sexigesimal strings.
  * New Axis Lock feature to limit joystick to specific motion
    axis.
  * INDI server now reaps zombie processes as they appear.
  * EQMod support for AUX encoder values. ST4 Guide Rates settings.
    PPEC Switches.
  * Fix for TELESCOPE_PIER_SIDE implementation in EQMod driver.
  * Several fixes for Pulsar2 driver.
  * Fix SER file generation for color frames. Added timestamps for
    each recorded frame. Support subframed video streams.
  * Debug and Logging options can be saved in the config file.
  * New CCD_TRANSFER_FORMAT property.
  * libindi can now be compiled under MacOS and Cygwin. Non-Linux
    specific 3rd party drivers are also supported under MacOS and
    Cygwin.
  * When a request for snooped is sent, it is echoed to drivers so
    that they send the snopped value immediately if it exists.
  * libindi shared library is dropped. libindi now offsers
    indidriver (shared), indiclient (static), and indiclientqt5
    (static) libraries.
  * Legacy drivers removed: SkyCommander, Intelliscope, MagellanI,
    TruTech, SBIG STV.
- Added new subpackage libindi-plugins.
- libindi1 was dropped from the package source. Obsolete it in
  libindi-plugins in order to fix conflicts due to %%{_libdir}/indi/
  previously contained in libindi1.
- Removed libindi-generate-tarball.sh script (not needed anymore).
- Removed no-return-in-nonvoid-function.patch (fixed upstream).
- Added a patch (bufferoverflow.patch) to fix "Statement is
  overflowing a buffer" post-build check errors.
* Sat Jan 21 2017 asterios.dramis@gmail.com
- Update to version 1.3.1:
  * Support for Optec IFW Filter Wheel.
  * Added new method in base client getBLOBMode to retrieve
    previously set BLOB mode for a device/property pair.
  * QHY driver use software binning by default for all cameras.
  * Minor bug fixes and improvements across all drivers.
  From version 1.3.0:
  * Support for Shelyak eShel spectrograph.
  * Support for NStep focuser.
  * Support for ASI Filter Wheel.
  * Support for OneStep Telescope Controller.
  * Support for Moravian CCD driver.
  * Support for  GigE machine vision cameras.
  * Experimental SSAG CCD driver.
  * Adding support for fast BLOB with ENCLEN. With Fast blob mode
    enabled, blob performance is now significantly faster.
  * FITS Min/Max calculations are disabled by default to save
    processing time unless explicitly enabled by the user at
    compile time.
  * Qt5 based client class is added to enable multiplatform client
    development.
  * New significantly faster base64 encoding/decoding routines.
  * Selectable alignment modes for INDI EQMod that includes
    built-in EQMod alignment and INDI Alignment Subsystem.
  * CCD sequence queue number is no longer limited to 999.
  * More Starlight Xpress CCDs cameras supported.
  * Updated Starlight Xpress Adaptive Optics driver.
  * Updated Temma Takahashi mount driver.
  * Updated Apogee CCD driver.
  * Updated QHY CCD driver with numerous fixes.
  * Updated FLI CCD driver.
  * Updated Pulasr2 driver.
  * Updated ASI CCD with support for arm64 architecture, 1600 model
    and a lot more.
  * Significant improvements to GPhoto driver including better
    support for Nikon DSLRs.
  * Improved GPSd driver.
  * New CCD_FILE_PATH property to indicate remote file path.
  * New TELESCOPE_PIER_SIDE property.
  * Dome & Telescope Scripting Gateway added.
  * Added support for servos in Indiduino
  * Fix BuiltinMathPlugin crash for Southern Hemisphere
  * Add scope park aware feature to the rolloff roof simulator
  * INDI Logs are now stored under ~/.indi/logs and arranged by
    date and time per driver.
- Removed support for openSUSE < 11.4.
- Added new build requirement Qt5Network.
- Removed libindi-implicit-pointer-decl.patch (fixed upstream).
- Adjust no-return-in-nonvoid-function.patch for this release
  (patch upstream).
- Starting with release 1.3 INDI ships libindi and 3rdparty stuff
  (drivers and external libraries, not necessary for libindi) in
  one big tar archive. The 3rdparty stuff cannot be installed
  without libindi already installed.
  Added a script "libindi-generate-tarball.sh" to generate a clean
  tarball containing only the library (based on one from Fedora).
* Sun Jun 26 2016 asterios.dramis@gmail.com
- Update to version 1.2.0:
  * Support for Davis Vantage Pro/Pro2/Vue Weather Station.
  * Support for XAGYL Filter Wheel.
  * Support for Optec Flip Flat.
  * Support for Pulasr2 mount.
  * Support for JMI Smart Focus.
  * Support for GPS driver based on gpsd.
  * 3rdParty: QHY Updates and Fixes. Color camera support.
  * 3rdParty: GPhoto focus and live streaming fixes.
  * 3rdParty: Starlight Xpress support for multiple identical
    devices and driver improvements.
  * 3rdParty: ASI updated to latest SDK. Temperature readout for
    all cameras. ROI & Cooler fixes.
  * FocusLynx: Support 2 focusers.
  * Celestron: Support pulse guiding. Support hibernation and wakup
    on supported firmware.
  * SynScan: Complete rewrite to support latest features in the
    firmware.
  * GPhoto: Mirror lock support before capture.
  * RoboFocus: Update to comply to INDI::Focus standards.
  * SBIG: Support for connecting to Ethernet based CCDs.
  * ZEQ25: Updates and fixes.
  * MaxDomeII: Driver updated and tested under latest INDI::Dome
    standards.
  * QSI: Added anti-blooming option.
  * INDI WatchDog driver: Can be configured to perform observatory
    shutdown.
  * EQMod: Initial support for INDI Alignment Subsystem. Do not
    stop motor in low speed (guiding issue).
  * Temma: Complete rewrite based on INDI::Telescope and using INDI
    Alignment Subsystem.
  * AutoDome park feature in Dome devices.
  * Fix Crash on ODroid.
  * Added Meta-Weather driver to aggregate weather data from
    multiple sources.
  * Support for remotely controller dust caps and light box devices.
  * Handle 16bit images in Rapid Guide mode.
  * BaseClient non-blocking connect support.
  * Unified Streaming/Recording support for multiple drivers
    (ASI/QHY/V4L2).
  From version 1.1.0:
  * INDI::Weather for support of weather devices.
  * INDI::GPS for support of GPS devices.
  * WunderGround weather driver.
  * Meade DSI I & II support.
  * FocusLynx focuser support.
  * PerfectStar focuser support.
  * World Coordinate System (WCS) support in generated FITS.
  * Updated Losmany driver.
  * New Celestron driver.
  * New IEQPro driver.
  * Support for custom parking in dome drivers.
  * Support Open Loop dome controllers.
  * Various QHY CCD & Filter Wheel fixes and QHY OSX support.
  * SBIG External Guide CCD fixes.
  * Custom parking support for
    Celestron/Astrophysics/AstroElectronics/IEQPro
  * Updated ASI ZWO drivers.
  * Updated Apogee library. Improved NET support in INDI Apogee
    driver.
  * Standarizing mount slew and track rates.
  * Video4Linux 2 fixes and improvements: (16bpp pixel formats(Y16
    and BYR2), pwc flashled, colorSpace/linearization, stacking),
    Simutaneous record/stream/exp. Stream rate divisor. Rec. file
    patterns.
  * EQMod fixes: Keep tracking after joystick motion is stopped.
    Park initialization always set encoders.
  * Improved support for drivers on ARM architecture.
  * Improved logging capability.
  * Deprecated: LX200Legacy and indimain library.
- Rebased libindi-implicit-pointer-decl.patch to apply cleanly.
- Adjust no-return-in-nonvoid-function.patch for this release
  (patch upstream).
- Added new build requirement libcurl-devel.
* Sun Jul  5 2015 crrodriguez@opensuse.org
- libindi-implicit-pointer-decl.patch: fix rpmlint implicit
  declaration warnings
- BuildRequire libusb-1.0 not libusb-devel
- Build C++ code with at least -fvisibility-inlines-hidden.
* Sat Feb 21 2015 asterios.dramis@gmail.com
- Update to version 1.0.0:
  * 3rdparty: Support for QHY CCDs and CFWs (BETA).
  * 3rdparty: Support for Meade DSI (BETA).
  * 3rdparty: Support for FFMV cameras.
  * Support for STAR2000.
  * Support for Baader dome.
  * Support for Baader SteelDrive focuser.
  * Support for dome slaving (BETA).
  * Subframing and debayer support in GPhoto driver.
  * Improved CFW handling and external tracking CCD for SBIG CCDs.
  * Add debayer support for color cameras with user-configurable
    options. Debayer is performed at the client level.
  * Fixed deinterlacing and subframing support in Starlight Xpress
    drivers.
  * Fixed issues with joystick support in some drivers. Added
    joystick support to focuser and filter wheels.
  * Improvements in generation of FITS header.
  * Improvement in performance of some drivers under SBCs like
    Raspberry PI.
  * Added fan and readout speed controls to QSI CCD.
  * Fixed locale issue in INDI driver.
  * Fixed regression in LX200Basic driver.
  * Fixed issue with INDI Server resetting environment variable for
    skeleton and config files.
  * Various fixes for loading/saving of user configuration.
  From version 0.9.9:
  * Thread-safe INDI Library.
  * Support for Rigelsys NFocus Focuser driver.
  * 3rdparty: Additional VID/PID for QHY.
  * 3rdparty: added USB Bandiwdth control for ZWO Optical cameras.
  * 3rdparty: Updated and improved INDI Apogee driver and Apogee
    Library major update.
  * 3rdparty: Live preview support for GPhoto driver. Tested on
    Canon.
  * 3rdparty: Various bugfixes and improvements in INDI SBIG driver
    including working guide chip support.
  * 3rdparty: Fixed time drift error in EQMod. Added Horizon
    limits. Added Backlash comp.
  * Updated and improved Image Agent.
  * Improved Astrophysics driver support.
  * Fixed location bug in Celestron GPS driver.
  * Additional information in FITS header such as filter name.
  * Joystick support for focuser and filter wheel devices.
  * Added option to enable local & remote save for FITS images in
    all CCD drivers.
  * Older V4L driver is deprecated (indi_v4l_legacy) and is
    replaced by indi_v4l2_ccd
  * V4L2: added recording (SER files) for use with Registax
  * V4L2: added RGGB & UYVY pixel format support to V4L2 drivers.
  * V4L2: fixed LX long exposure times.
  * Updated and improved tutorials.
  * Fixed few OSX compatibility issues.
  * Various bug fixes and improvements.
  From version 0.9.8:
  * Support for Telescope Alignment Subsystem Infrastructure. This
    includes an implementation of Markley's singular value
    decomposition (SVD) based algorithm for the computation of
    sky/telescope coordinate conversion transforms, in addition to
    multiple plugin support.
  * Suppprt for SkyWatcherAPI Mount with Alignment Subsystem.
  * Support for ZWO Optics ASI Cameras (3rd party)
  * Support for AAG Cloud Watcher station (3rd Party).
  * Support for MoonLite focusers.
  * Support for Fishcamp CCDs (3rd Party).
  * Support for Imager Agent.
  * Improved EQMod driver including custom parking position.
  * New and updated Astrophysics mount driver.
  * New and updated QHY CCD Driver (3rd Party).
  * New and improved GPhoto driver to support DSLRs.
  * New and updated Video4Linux CCD Driver including support for
    long exposures (LX) and Imaging Source cameras.
  * New and improved Apogee CCD driver.
  * Improved support for SBIG CCDs including ST-I.
  * Updated and improved TCFS Focuser drivers.
  * Drivers migrated to libusb 1.0 framework.
  * Rapid Guide Support for CCD Drivers.
  * Improved compatibility with Mac OSX including INDI Server and
    GUI.
  * Various bug fixes and improvements.
- Added new build requirements gsl-devel and libjpeg-devel.
- Adjust no-return-in-nonvoid-function.patch for this release
  (patch upstream).
- Removed libindi-aarch64.patch (fixed upstream).
* Sat Feb  1 2014 hrvoje.senjan@gmail.com
- Update to version 0.9.7:
  * Support for EQMod mount driver (3rd party).
  * Support for ATIK CCDs and Filter Wheels (3rd party).
  * Support for Shoestring Astronomy FCUSB (3rd party).
  * Support for joysticks and game pads under Linux.
  * LX200, Celeston, and EQMod drivers support joystick input.
  * Improved LX200 & Celestron telescope drivers.
  * Improved simulator drivers.
  * INDI server support for multiple devices per driver.
  * New universal logging and debugging framework for INDI
    developers.
  * Fixed an issue in TCFS driver where a connect may fail if
    focuser is put into sleep mode.
  * Fixed an issue where the client thread in INDI::BaseClient
    is not being terminated gracefully in blocking mode.
  * Fixed an issue involving non-English clients that utilize
    INDI client library to communicate with INDI server.
  * Fixed an issue where some properties in some drivers are
    sent before getting defined by INDI.
- Droped udev_rules_dir_configurable.patch, not required anymore
- Adjust no-return-in-nonvoid-function.patch for this release
* Wed Mar 27 2013 schwab@suse.de
- libindi-aarch64.patch: No port I/O on aarch64
* Wed Nov 28 2012 asterios.dramis@gmail.com
- Update to version 0.9.6:
  * Support for Starlight Xpress Adaptive Optics unit.
  * Improved support for Startlight Xpress CCDs and Filter wheels.
  * Support for Arduino boards, with customizable drivers for common
    observatory auxiliary devices.
  * Support for GPUSB Guide Port Interface.
  * Improved support for QSI CCDs and Filter wheels.
  * Support for filters with absolute positioning.
  * Support for cameras with guiding chip.
  * Fixed INDI server FIFO CPU utilization bug.
  * Fixed various bugs with v4l drivers due to code regression.
  * Improved support for Mac OS X.
  * Improved simulators.
  * _REQUEST properties are now deprecated.
  * Updated tutorials and API.
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix some new "no-return-in-nonvoid-function" rpm
  post-build check errors.
- Added a patch (udev_rules_dir_configurable.patch) to make
  "UDEVRULES_INSTALL_DIR" configurable.
- Added pkgconfig(udev) as build requirement in order to install the udev rules
  file in the correct directory.
* Thu Sep 27 2012 asterios.dramis@gmail.com
- Update to version 0.9.5:
  * Focuser simulator driver.
  * CCD, Telescope, Focuser, and Filter simulators improvements including
    periodic error effects, FWHM, and more.
  * Major improvements to INDI Base Library and INDI Client Library.
  * Fixed minor bugs in LX200 Generic, LX200 FS2, Magellan, and Celestron
    drivers.
  * Minor bugfixes and improvements.
  * Fixed color buffer problem in V4L drivers.
  * Numerous bug fixes and minor improvements.
  From 0.9.1:
  * Bugfix release.
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix some new "no-return-in-nonvoid-function" rpm
  post-build check errors.
- Removed libindi-usleep.patch that fixed compilation with gcc-4.7 (fixed
  upstream).
* Tue May 22 2012 asterios.dramis@gmail.com
- Removed cfitsio_link_libs.patch (not needed after the update of cfitsio
  package and cfitsio.pc fix regarding library linking).
* Wed Mar 14 2012 asterios.dramis@gmail.com
- Added a patch (taken from Fedora) to fix compilation with gcc-4.7.
* Thu Jan 19 2012 asterios.dramis@gmail.com
- Update to version 0.9:
  * INDI::Base drivers are now used for most classes of astronomical
    instruments.
  * New iEQ45 GoTo German Equatorial Mount Driver.
  * New improved QSI CCD & Filter driver.
  * New improved Starlight Xpress CCD & Filter driver.
  * New improved RoboFocus driver.
  * libboost is no longer required to build libindi.
  * Improved support for building on non-Linux OSes.
  * Numerous bug fixes and minor improvements.
- Removed the following patches:
  * bufferoverflowstrncat.patch (fixed upstream).
  * fix_symlinks.patch (fixed upstream).
  * libindi.pc_fix.patch (fixed upstream).
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix a new "no-return-in-nonvoid-function" rpm post-build
  check error.
- Replaced libindi-cfitsio.patch with cfitsio_link_libs.patch (fix missing
  "pthread" in target_link_libraries where needed).
- Spec file updates:
  * Removed boost-devel from BuildRequires (not needed anymore).
* Mon Dec 12 2011 idonmez@suse.com
- Fix build with new cfitsio
* Sun Sep 18 2011 asterios.dramis@gmail.com
- Update to version 0.8:
  * Starlight Xpress CCD and Filter Wheel.
  * EQ Synscan Mount.
  * TCFS Focuser.
  * QSI CCD.
  * Radio Astronomy Supplies Spectracyber Hydrogen Line Spectromet.
  From 0.7.1/0.7.2:
  * Fixed change filter bug in true technology filter wheel.
  * setINDI updated and improved.
  * Improved INDI::Mediator functionality.
  * Fixed buffer reading in INDI::BaseClient.
  * Add new tutorial for INDI::BaseClient.
  From 0.7.0:
  * Dynamic renaming of drivers upon run time.
  * Standard helper API to create and utilize INDI clients.
  * Ability to load driver properties from an external XML file.
  * Ability to write/read XML configuration files for driver values to be
    loaded at run time.
  * Facilitating debugging and simulation of drivers.
  * New C++ framework to facilitate the development of new INDI drivers.
  * New 3rd party drivers!
  * Several bug fixes for current drivers and framework.
- Spec file updates:
  * Added boost-devel in BuildRequires.
- Added 2 patches to fix rpm post-build check errors "bufferoverflowstrncat"
  and "no-return-in-nonvoid-function".
* Sat May 21 2011 asterios.dramis@gmail.com
- Update to version 0.6.2:
  * Build related updates.
  From 0.6.1:
  * Updating drivers.xml to comply to new XML structure for group and devices
    metadata descriptions.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changes in Url, Group, Summary and %%description.
  * Changes in the fix for lib64 installation.
  * Minor other updates.
- Added 2 patches to fix the symlinks installation and the pkgconfig file based
  on Gentoo.
* Thu Apr  1 2010 llunak@novell.com
- Add libfli as a buildrequire
* Fri Mar 20 2009 crrodriguez@suse.de
- run ldconfig
- use RPM_OPT_FLAGS
- fix -devel package dependencies
* Tue Jan  6 2009 dmueller@suse.de
- Initial package (v0.6)
